package com.aucma.report.mapper;

import java.util.List;
import com.aucma.report.domain.BoxTemperatureHistory;

/**
 * 测温记录报表Mapper接口
 * 
 * @author Yinq
 * @date 2024-03-13
 */
public interface BoxTemperatureHistoryMapper 
{
    /**
     * 查询测温记录报表
     * 
     * @param objId 测温记录报表主键
     * @return 测温记录报表
     */
    public BoxTemperatureHistory selectBoxTemperatureHistoryByObjId(Long objId);

    /**
     * 查询测温记录报表列表
     * 
     * @param boxTemperatureHistory 测温记录报表
     * @return 测温记录报表集合
     */
    public List<BoxTemperatureHistory> selectBoxTemperatureHistoryList(BoxTemperatureHistory boxTemperatureHistory);

    /**
     * 新增测温记录报表
     * 
     * @param boxTemperatureHistory 测温记录报表
     * @return 结果
     */
    public int insertBoxTemperatureHistory(BoxTemperatureHistory boxTemperatureHistory);

    /**
     * 修改测温记录报表
     * 
     * @param boxTemperatureHistory 测温记录报表
     * @return 结果
     */
    public int updateBoxTemperatureHistory(BoxTemperatureHistory boxTemperatureHistory);

    /**
     * 删除测温记录报表
     * 
     * @param objId 测温记录报表主键
     * @return 结果
     */
    public int deleteBoxTemperatureHistoryByObjId(Long objId);

    /**
     * 批量删除测温记录报表
     * 
     * @param objIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBoxTemperatureHistoryByObjIds(Long[] objIds);
}
